Export Package VRC : bcB40Pc4ca20
Update compared VRC:   B40 c4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
dbcckon                             B40Pc4ca20
dbcreje                             B40Pc4ca20
dbcstc.cnln                         B40Pc4ca20
dbcynna                             B40Pc4ca20
tbcsci000                           B40Pc4ca20
tbcstc000                           B40Pc4ca20
tbcstd000                           B40Pc4ca20
tbcstf000                           B40Pc4ca20
tbcstf013                           B40Pc4ca20
tbcstf014                           B40Pc4ca20
tbcsti000                           B40Pc4ca20
tbcstp000                           B40Pc4ca20
tbcstp004                           B40Pc4ca20
tbcstp005                           B40Pc4ca20
tbcsts000                           B40Pc4ca20
tbcsts007                           B40Pc4ca20
tbcswh000                           B40Pc4ca20
tbcswh007                           B40Pc4ca20
tbcswh009                           B40Pc4ca20
tbcswh010                           B40Pc4ca20
sbcsci0100m000                      B40Pc4ca20
sbcstc0100m000                      B40Pc4ca20
sbcstc0117m000                      B40Pc4ca20
sbcstc0131m000                      B40Pc4ca20
sbcstc0207s000                      B40Pc4ca20
sbcstf0100m000                      B40Pc4ca20
sbcstf0109m000                      B40Pc4ca20
sbcstf0113m000                      B40Pc4ca20
sbcstf0114m000                      B40Pc4ca20
sbcstp0104m000                      B40Pc4ca20
sbcstp0105m000                      B40Pc4ca20
sbcsts0105m000                      B40Pc4ca20
sbcsts0107m000                      B40Pc4ca20
sbcswh0109m000                      B40Pc4ca20
sbcswh0110m000                      B40Pc4ca20
sbcswh0110m100                      B40Pc4ca20
pbcdllfbcttf001                     B40Pc4ca20 (without source)
pbcdllfbcttf002                     B40Pc4ca20 (without source)
pbcdllfbcttf006                     B40Pc4ca20 (without source)
pbcdllfcisli120                     B40Pc4ca20 (without source)
pbcdllfqmptc011                     B40Pc4ca20 (without source)
pbcdllfqmptc130                     B40Pc4ca20 (without source)
pbcdllfqmptc131                     B40Pc4ca20 (without source)
pbcdllftccom000                     B40Pc4ca20 (without source)
pbcdllftccom136                     B40Pc4ca20 (without source)
pbcdllftccom139                     B40Pc4ca20 (without source)
pbcdllftccom710                     B40Pc4ca20 (without source)
pbcdllftccom997                     B40Pc4ca20 (without source)
pbcdllftcibd999                     B40Pc4ca20 (without source)
pbcdllftcmcs010                     B40Pc4ca20 (without source)
pbcdllftcmcs040                     B40Pc4ca20 (without source)
pbcdllftctax000                     B40Pc4ca20 (without source)
pbcdllftdipu001                     B40Pc4ca20 (without source)
pbcdllftdipu002                     B40Pc4ca20 (without source)
pbcdllftdipu010                     B40Pc4ca20 (without source)
pbcdllftdipu100                     B40Pc4ca20 (without source)
pbcdllftdisa001                     B40Pc4ca20 (without source)
pbcdllftdpur000                     B40Pc4ca20 (without source)
pbcdllftdpur301                     B40Pc4ca20 (without source)
pbcdllftdpur306                     B40Pc4ca20 (without source)
pbcdllftdpur351                     B40Pc4ca20 (without source)
pbcdllftdpur450                     B40Pc4ca20 (without source)
pbcdllftdpur451                     B40Pc4ca20 (without source)
pbcdllftdsls000                     B40Pc4ca20 (without source)
pbcdllftdsls407                     B40Pc4ca20 (without source)
pbcdllftfacp000                     B40Pc4ca20 (without source)
pbcdllftfcmg000                     B40Pc4ca20 (without source)
pbcdllftfcmg001                     B40Pc4ca20 (without source)
pbcdllftfcmg003                     B40Pc4ca20 (without source)
pbcdllftfcmg101                     B40Pc4ca20 (without source)
pbcdllftfcmg110                     B40Pc4ca20 (without source)
pbcdllftfcmg112                     B40Pc4ca20 (without source)
pbcdllftfcmg204                     B40Pc4ca20 (without source)
pbcdllftfcmg301                     B40Pc4ca20 (without source)
pbcdllftfcmg500                     B40Pc4ca20 (without source)
pbcdllftfcmg502                     B40Pc4ca20 (without source)
pbcdllftfcmg505                     B40Pc4ca20 (without source)
pbcdllftfgld004                     B40Pc4ca20 (without source)
pbcdllfticst001                     B40Pc4ca20 (without source)
pbcdllftipcf000                     B40Pc4ca20 (without source)
pbcdllftipcs025                     B40Pc4ca20 (without source)
pbcdllftirou001                     B40Pc4ca20 (without source)
pbcdllftisfc000                     B40Pc4ca20 (without source)
pbcdllftisfc001                     B40Pc4ca20 (without source)
pbcdllftisfc010                     B40Pc4ca20 (without source)
pbcdllftitrp000                     B40Pc4ca20 (without source)
pbcdllftpctm000                     B40Pc4ca20 (without source)
pbcdllftpctm020                     B40Pc4ca20 (without source)
pbcdllftpctm100                     B40Pc4ca20 (without source)
pbcdllftpctm110                     B40Pc4ca20 (without source)
pbcdllftppdm043                     B40Pc4ca20 (without source)
pbcdllftppdm600                     B40Pc4ca20 (without source)
pbcdllftppin010                     B40Pc4ca20 (without source)
pbcdllftppin011                     B40Pc4ca20 (without source)
pbcdllftppin020                     B40Pc4ca20 (without source)
pbcdllftpppc005                     B40Pc4ca20 (without source)
pbcdllftpppc200                     B40Pc4ca20 (without source)
pbcdllftpppc211                     B40Pc4ca20 (without source)
pbcdllftpppc215                     B40Pc4ca20 (without source)
pbcdllftpppc305                     B40Pc4ca20 (without source)
pbcdllftpppc350                     B40Pc4ca20 (without source)
pbcdllftppss200                     B40Pc4ca20 (without source)
pbcdllftppss615                     B40Pc4ca20 (without source)
pbcdllftpptc220                     B40Pc4ca20 (without source)
pbcdllftpptc230                     B40Pc4ca20 (without source)
pbcdllftpptc240                     B40Pc4ca20 (without source)
pbcdllftpptc250                     B40Pc4ca20 (without source)
pbcdllftpptc260                     B40Pc4ca20 (without source)
pbcdllftsacm220                     B40Pc4ca20 (without source)
pbcdllftscfg200                     B40Pc4ca20 (without source)
pbcdllftsctm110                     B40Pc4ca20 (without source)
pbcdllftsmdm030                     B40Pc4ca20 (without source)
pbcdllftsmdm200                     B40Pc4ca20 (without source)
pbcdllftsmdm400                     B40Pc4ca20 (without source)
pbcdllftssoc205                     B40Pc4ca20 (without source)
pbcdllftsspc210                     B40Pc4ca20 (without source)
pbcdllfwhina310                     B40Pc4ca20 (without source)
pbcdllfwhinh000                     B40Pc4ca20 (without source)
pbcdllfwhinp100                     B40Pc4ca20 (without source)
pbcdllfwhwmd230                     B40Pc4ca20 (without source)
pbcdllfwhwmd302                     B40Pc4ca20 (without source)
pbcdllmcisli000                     B40Pc4ca20 (without source)
pbcdllmcisli220                     B40Pc4ca20 (without source)
pbcdllmcisli305                     B40Pc4ca20 (without source)
pbcdllmcprpd100                     B40Pc4ca20 (without source)
pbcdllmcprrp100                     B40Pc4ca20 (without source)
pbcdllmtccom130                     B40Pc4ca20 (without source)
pbcdllmtcibd001                     B40Pc4ca20 (without source)
pbcdllmtcibd402                     B40Pc4ca20 (without source)
pbcdllmtcmcs003                     B40Pc4ca20 (without source)
pbcdllmtcmcs036                     B40Pc4ca20 (without source)
pbcdllmtdpcg030                     B40Pc4ca20 (without source)
pbcdllmtdpur100                     B40Pc4ca20 (without source)
pbcdllmtdpur101                     B40Pc4ca20 (without source)
pbcdllmtdpur150                     B40Pc4ca20 (without source)
pbcdllmtdpur151                     B40Pc4ca20 (without source)
pbcdllmtdpur401                     B40Pc4ca20 (without source)
pbcdllmtdsls401                     B40Pc4ca20 (without source)
pbcdllmtdsta000                     B40Pc4ca20 (without source)
pbcdllmtfacp240                     B40Pc4ca20 (without source)
pbcdllmtfacp250                     B40Pc4ca20 (without source)
pbcdllmticst002                     B40Pc4ca20 (without source)
pbcdllmtsctm300                     B40Pc4ca20 (without source)
pbcdllmtssoc000                     B40Pc4ca20 (without source)
pbcdllmtssoc200                     B40Pc4ca20 (without source)
pbcdllmtssoc220                     B40Pc4ca20 (without source)
pbcdllmtssoc850                     B40Pc4ca20 (without source)
pbcdllmtssoc860                     B40Pc4ca20 (without source)
pbcdllmtsspc130                     B40Pc4ca20 (without source)
pbcdllmwhinh200                     B40Pc4ca20 (without source)
pbcdllmwhinr110                     B40Pc4ca20 (without source)
pbcdllmwhltc100                     B40Pc4ca20 (without source)
pbcdllmwhwmd215                     B40Pc4ca20 (without source)
pbcintdll0000                       B40Pc4ca20 (without source)
pbcintdll0005                       B40Pc4ca20 (without source)
pbcintdll0007                       B40Pc4ca20 (without source)
pbcintdll0099                       B40Pc4ca20 (without source)
pbcintdll1100                       B40Pc4ca20 (without source)
pbcintdll1102                       B40Pc4ca20 (without source)
pbcintdll1104                       B40Pc4ca20 (without source)
pbcmttdll0004                       B40Pc4ca20 (without source)
pbcmttjvdwtest                      B40Pc4ca20 (without source)
pbcsci000                           B40Pc4ca20 (without source)
pbcsci0100                          B40Pc4ca20 (without source)
pbcscp003                           B40Pc4ca20 (without source)
pbcsqmdll0001                       B40Pc4ca20 (without source)
pbcstc000                           B40Pc4ca20 (without source)
pbcstc002                           B40Pc4ca20 (without source)
pbcstc008                           B40Pc4ca20 (without source)
pbcstc0100                          B40Pc4ca20 (without source)
pbcstc0124                          B40Pc4ca20 (without source)
pbcstc017                           B40Pc4ca20 (without source)
pbcstc0207                          B40Pc4ca20 (without source)
pbcstc021                           B40Pc4ca20 (without source)
pbcstc024                           B40Pc4ca20 (without source)
pbcstc029                           B40Pc4ca20 (without source)
pbcstc031                           B40Pc4ca20 (without source)
pbcstcdll0007                       B40Pc4ca20 (without source)
pbcstcdll0015                       B40Pc4ca20 (without source)
pbcstf000                           B40Pc4ca20 (without source)
pbcstf0100                          B40Pc4ca20 (without source)
pbcstf0113                          B40Pc4ca20 (without source)
pbcstf0114                          B40Pc4ca20 (without source)
pbcstf013                           B40Pc4ca20 (without source)
pbcstf014                           B40Pc4ca20 (without source)
pbcstfdll1001                       B40Pc4ca20 (without source)
pbcsti000                           B40Pc4ca20 (without source)
pbcsti003                           B40Pc4ca20 (without source)
pbcsti0100                          B40Pc4ca20 (without source)
pbcstidll0003                       B40Pc4ca20 (without source)
pbcstp000                           B40Pc4ca20 (without source)
pbcstp004                           B40Pc4ca20 (without source)
pbcstp005                           B40Pc4ca20 (without source)
pbcstp0100                          B40Pc4ca20 (without source)
pbcstp0104                          B40Pc4ca20 (without source)
pbcstp0105                          B40Pc4ca20 (without source)
pbcstpdll0002                       B40Pc4ca20 (without source)
pbcstpdll1001                       B40Pc4ca20 (without source)
pbcsts000                           B40Pc4ca20 (without source)
pbcsts005                           B40Pc4ca20 (without source)
pbcsts006                           B40Pc4ca20 (without source)
pbcsts007                           B40Pc4ca20 (without source)
pbcsts0100                          B40Pc4ca20 (without source)
pbcsts0107                          B40Pc4ca20 (without source)
pbcstsdll1001                       B40Pc4ca20 (without source)
pbcswh000                           B40Pc4ca20 (without source)
pbcswh002                           B40Pc4ca20 (without source)
pbcswh007                           B40Pc4ca20 (without source)
pbcswh009                           B40Pc4ca20 (without source)
pbcswh010                           B40Pc4ca20 (without source)
pbcswh0100                          B40Pc4ca20 (without source)
pbcswh0102                          B40Pc4ca20 (without source)
pbcswh0109                          B40Pc4ca20 (without source)
pbcswh0110                          B40Pc4ca20 (without source)
pbcswh01101                         B40Pc4ca20 (without source)
fbcsci0100m00012                    B40Pc4ca20
fbcsfm0100m00042                    B40Pc4ca20
fbcstc0100m00012                    B40Pc4ca20
fbcstc0100m00022                    B40Pc4ca20
fbcstc0100m00082                    B40Pc4ca20
fbcstc0100m00092                    B40Pc4ca20
fbcstc0100m00102                    B40Pc4ca20
fbcstc0100m00112                    B40Pc4ca20
fbcstc0100m00122                    B40Pc4ca20
fbcstd0100m00022                    B40Pc4ca20
fbcstd0100m00032                    B40Pc4ca20
fbcstd0100m00042                    B40Pc4ca20
fbcstf0100m00012                    B40Pc4ca20
fbcstf0100m00032                    B40Pc4ca20
fbcstf0113m00012                    B40Pc4ca20
fbcstf0114m00012                    B40Pc4ca20
fbcsti0100m00012                    B40Pc4ca20
fbcsti0100m00032                    B40Pc4ca20
fbcstp0100m00012                    B40Pc4ca20
fbcstp0100m00022                    B40Pc4ca20
fbcstp0104m00012                    B40Pc4ca20
fbcstp0105m00012                    B40Pc4ca20
fbcsts0100m00022                    B40Pc4ca20
fbcsts0107m00012                    B40Pc4ca20
fbcswh0100m00012                    B40Pc4ca20
fbcswh0107m00012                    B40Pc4ca20
fbcswh0108m00012                    B40Pc4ca20
fbcswh0109m00012                    B40Pc4ca20
fbcswh0110m00012                    B40Pc4ca20
fbcswh0110m10012                    B40Pc4ca20
cbcsci00001                         B40Pc4ca20
cbcsci00002                         B40Pc4ca20
cbcsci00003                         B40Pc4ca20
cbcstc00004                         B40Pc4ca20
cbcstc00107                         B40Pc4ca20
cbcstp00008                         B40Pc4ca20
cbcstp00009                         B40Pc4ca20
cbcstp00010                         B40Pc4ca20
cbcstp00011                         B40Pc4ca20
cbcstp00012                         B40Pc4ca20
cbcstp00013                         B40Pc4ca20
cbcstp00014                         B40Pc4ca20
cbcstp00015                         B40Pc4ca20
cbcstp00016                         B40Pc4ca20
cbcstp00017                         B40Pc4ca20
cbcswh00014                         B40Pc4ca20
cbcswh00015                         B40Pc4ca20
cbcswh00016                         B40Pc4ca20
cbcswh00017                         B40Pc4ca20
bbcswh0001                          B40Pc4ca20 (with source)
bbcswh0002                          B40Pc4ca20 (with source)
bbcswh0003                          B40Pc4ca20 (with source)
bbcswh0004                          B40Pc4ca20 (with source)
bbcswh0005                          B40Pc4ca20 (with source)
bbcswh0006                          B40Pc4ca20 (with source)
bbcswh0007                          B40Pc4ca20 (with source)
bbcswh0008                          B40Pc4ca20 (with source)
bbcswh0009                          B40Pc4ca20 (with source)
bbcswh0010                          B40Pc4ca20 (with source)
mbcstf0000100112                    B40Pc4ca20
mbcstf0000200112                    B40Pc4ca20
mbcstp0000200112                    B40Pc4ca20
mbcsts0000100112                    B40Pc4ca20
mbcsts0000200112                    B40Pc4ca20
mbcsts0000300112                    B40Pc4ca20
mbcswh0000200112                    B40Pc4ca20
obcdllfbcttf001                     B40Pc4ca20
obcdllfbcttf002                     B40Pc4ca20
obcdllfbcttf006                     B40Pc4ca20
obcdllfcisli120                     B40Pc4ca20
obcdllfqmptc011                     B40Pc4ca20
obcdllfqmptc130                     B40Pc4ca20
obcdllfqmptc131                     B40Pc4ca20
obcdllftccom000                     B40Pc4ca20
obcdllftccom136                     B40Pc4ca20
obcdllftccom139                     B40Pc4ca20
obcdllftccom710                     B40Pc4ca20
obcdllftccom997                     B40Pc4ca20
obcdllftcibd999                     B40Pc4ca20
obcdllftcmcs010                     B40Pc4ca20
obcdllftcmcs040                     B40Pc4ca20
obcdllftctax000                     B40Pc4ca20
obcdllftdipu001                     B40Pc4ca20
obcdllftdipu002                     B40Pc4ca20
obcdllftdipu010                     B40Pc4ca20
obcdllftdipu100                     B40Pc4ca20
obcdllftdisa001                     B40Pc4ca20
obcdllftdpur000                     B40Pc4ca20
obcdllftdpur301                     B40Pc4ca20
obcdllftdpur306                     B40Pc4ca20
obcdllftdpur351                     B40Pc4ca20
obcdllftdpur450                     B40Pc4ca20
obcdllftdpur451                     B40Pc4ca20
obcdllftdsls000                     B40Pc4ca20
obcdllftdsls407                     B40Pc4ca20
obcdllftfacp000                     B40Pc4ca20
obcdllftfcmg000                     B40Pc4ca20
obcdllftfcmg001                     B40Pc4ca20
obcdllftfcmg003                     B40Pc4ca20
obcdllftfcmg101                     B40Pc4ca20
obcdllftfcmg110                     B40Pc4ca20
obcdllftfcmg112                     B40Pc4ca20
obcdllftfcmg204                     B40Pc4ca20
obcdllftfcmg301                     B40Pc4ca20
obcdllftfcmg500                     B40Pc4ca20
obcdllftfcmg502                     B40Pc4ca20
obcdllftfcmg505                     B40Pc4ca20
obcdllftfgld004                     B40Pc4ca20
obcdllfticst001                     B40Pc4ca20
obcdllftipcf000                     B40Pc4ca20
obcdllftipcs025                     B40Pc4ca20
obcdllftirou001                     B40Pc4ca20
obcdllftisfc000                     B40Pc4ca20
obcdllftisfc001                     B40Pc4ca20
obcdllftisfc010                     B40Pc4ca20
obcdllftitrp000                     B40Pc4ca20
obcdllftpctm000                     B40Pc4ca20
obcdllftpctm020                     B40Pc4ca20
obcdllftpctm100                     B40Pc4ca20
obcdllftpctm110                     B40Pc4ca20
obcdllftppdm043                     B40Pc4ca20
obcdllftppdm600                     B40Pc4ca20
obcdllftppin010                     B40Pc4ca20
obcdllftppin011                     B40Pc4ca20
obcdllftppin020                     B40Pc4ca20
obcdllftpppc005                     B40Pc4ca20
obcdllftpppc200                     B40Pc4ca20
obcdllftpppc211                     B40Pc4ca20
obcdllftpppc215                     B40Pc4ca20
obcdllftpppc305                     B40Pc4ca20
obcdllftpppc350                     B40Pc4ca20
obcdllftppss200                     B40Pc4ca20
obcdllftppss615                     B40Pc4ca20
obcdllftpptc220                     B40Pc4ca20
obcdllftpptc230                     B40Pc4ca20
obcdllftpptc240                     B40Pc4ca20
obcdllftpptc250                     B40Pc4ca20
obcdllftpptc260                     B40Pc4ca20
obcdllftsacm220                     B40Pc4ca20
obcdllftscfg200                     B40Pc4ca20
obcdllftsctm110                     B40Pc4ca20
obcdllftsmdm030                     B40Pc4ca20
obcdllftsmdm200                     B40Pc4ca20
obcdllftsmdm400                     B40Pc4ca20
obcdllftssoc205                     B40Pc4ca20
obcdllftsspc210                     B40Pc4ca20
obcdllfwhina310                     B40Pc4ca20
obcdllfwhinh000                     B40Pc4ca20
obcdllfwhinp100                     B40Pc4ca20
obcdllfwhwmd230                     B40Pc4ca20
obcdllfwhwmd302                     B40Pc4ca20
obcdllmcisli000                     B40Pc4ca20
obcdllmcisli220                     B40Pc4ca20
obcdllmcisli305                     B40Pc4ca20
obcdllmcprpd100                     B40Pc4ca20
obcdllmcprrp100                     B40Pc4ca20
obcdllmtccom130                     B40Pc4ca20
obcdllmtcibd001                     B40Pc4ca20
obcdllmtcibd402                     B40Pc4ca20
obcdllmtcmcs003                     B40Pc4ca20
obcdllmtcmcs036                     B40Pc4ca20
obcdllmtdpcg030                     B40Pc4ca20
obcdllmtdpur100                     B40Pc4ca20
obcdllmtdpur101                     B40Pc4ca20
obcdllmtdpur150                     B40Pc4ca20
obcdllmtdpur151                     B40Pc4ca20
obcdllmtdpur401                     B40Pc4ca20
obcdllmtdsls401                     B40Pc4ca20
obcdllmtdsta000                     B40Pc4ca20
obcdllmtfacp240                     B40Pc4ca20
obcdllmtfacp250                     B40Pc4ca20
obcdllmticst002                     B40Pc4ca20
obcdllmtsctm300                     B40Pc4ca20
obcdllmtssoc000                     B40Pc4ca20
obcdllmtssoc200                     B40Pc4ca20
obcdllmtssoc220                     B40Pc4ca20
obcdllmtssoc850                     B40Pc4ca20
obcdllmtssoc860                     B40Pc4ca20
obcdllmtsspc130                     B40Pc4ca20
obcdllmwhinh200                     B40Pc4ca20
obcdllmwhinr110                     B40Pc4ca20
obcdllmwhltc100                     B40Pc4ca20
obcdllmwhwmd215                     B40Pc4ca20
obcintdll0000                       B40Pc4ca20
obcintdll0005                       B40Pc4ca20
obcintdll0007                       B40Pc4ca20
obcintdll0099                       B40Pc4ca20
obcintdll1100                       B40Pc4ca20
obcintdll1102                       B40Pc4ca20
obcintdll1104                       B40Pc4ca20
obcmttdll0004                       B40Pc4ca20
obcmttjvdwtest                      B40Pc4ca20
obcsci000                           B40Pc4ca20
obcsci0100                          B40Pc4ca20
obcscp003                           B40Pc4ca20
obcsqmdll0001                       B40Pc4ca20
obcstc000                           B40Pc4ca20
obcstc002                           B40Pc4ca20
obcstc008                           B40Pc4ca20
obcstc0100                          B40Pc4ca20
obcstc0124                          B40Pc4ca20
obcstc017                           B40Pc4ca20
obcstc0207                          B40Pc4ca20
obcstc021                           B40Pc4ca20
obcstc024                           B40Pc4ca20
obcstc029                           B40Pc4ca20
obcstc031                           B40Pc4ca20
obcstcdll0007                       B40Pc4ca20
obcstcdll0015                       B40Pc4ca20
obcstf000                           B40Pc4ca20
obcstf0100                          B40Pc4ca20
obcstf0113                          B40Pc4ca20
obcstf0114                          B40Pc4ca20
obcstf013                           B40Pc4ca20
obcstf014                           B40Pc4ca20
obcstfdll1001                       B40Pc4ca20
obcsti000                           B40Pc4ca20
obcsti003                           B40Pc4ca20
obcsti0100                          B40Pc4ca20
obcstidll0003                       B40Pc4ca20
obcstp000                           B40Pc4ca20
obcstp004                           B40Pc4ca20
obcstp005                           B40Pc4ca20
obcstp0100                          B40Pc4ca20
obcstp0104                          B40Pc4ca20
obcstp0105                          B40Pc4ca20
obcstpdll0002                       B40Pc4ca20
obcstpdll1001                       B40Pc4ca20
obcsts000                           B40Pc4ca20
obcsts005                           B40Pc4ca20
obcsts006                           B40Pc4ca20
obcsts007                           B40Pc4ca20
obcsts0100                          B40Pc4ca20
obcsts0107                          B40Pc4ca20
obcstsdll1001                       B40Pc4ca20
obcswh000                           B40Pc4ca20
obcswh002                           B40Pc4ca20
obcswh007                           B40Pc4ca20
obcswh009                           B40Pc4ca20
obcswh010                           B40Pc4ca20
obcswh0100                          B40Pc4ca20
obcswh0102                          B40Pc4ca20
obcswh0109                          B40Pc4ca20
obcswh0110                          B40Pc4ca20
obcswh01101                         B40Pc4ca20
lbcbccnv010.orno                    B40Pc4ca20
lbcbcgen.slash                      B40Pc4ca20
lbcbcgen.source                     B40Pc4ca20
lbcbcgen.target                     B40Pc4ca20
lbcbcgensource                      B40Pc4ca20
lbcbcsci000.dpad                    B40Pc4ca20
lbcbcsci000.dptp                    B40Pc4ca20
lbcbcsci000.il01                    B40Pc4ca20
lbcbcsci000.il02                    B40Pc4ca20
lbcbcsci000.il03                    B40Pc4ca20
lbcbcsci000.il04                    B40Pc4ca20
lbcbcsci000.ild1                    B40Pc4ca20
lbcbcsci000.ild2                    B40Pc4ca20
lbcbcsci000.ild3                    B40Pc4ca20
lbcbcsci000.ild4                    B40Pc4ca20
lbcbcsci000.ngtd                    B40Pc4ca20
lbcbcsci000.ngti                    B40Pc4ca20
lbcbcsci0100.invl                   B40Pc4ca20
lbcbcsci0100.nrgr                   B40Pc4ca20
lbcbcstc.generate                   B40Pc4ca20
lbcbcstc000.rcIA                    B40Pc4ca20
lbcbcstc000.rcbl                    B40Pc4ca20
lbcbcstc000.rcdm                    B40Pc4ca20
lbcbcstc000.rcia                    B40Pc4ca20
lbcbcstc000.rcqt                    B40Pc4ca20
lbcbcstc000.rcrg                    B40Pc4ca20
lbcbcstc000.rcrj                    B40Pc4ca20
lbcbcstc000.rcte                    B40Pc4ca20
lbcbcstc000.tmtc                    B40Pc4ca20
lbcbcstd000.aitm                    B40Pc4ca20
lbcbcstf000.dlcd                    B40Pc4ca20
lbcbcstf000.dloc                    B40Pc4ca20
lbcbcstf013.anbr                    B40Pc4ca20
lbcbcstf013.dkey                    B40Pc4ca20
lbcbcstf013.lkey                    B40Pc4ca20
lbcbcstf013.loca                    B40Pc4ca20
lbcbcstf014.orno                    B40Pc4ca20
lbcbcstf014.pono                    B40Pc4ca20
lbcbcstf014.rcln                    B40Pc4ca20
lbcbcstf014.rcno                    B40Pc4ca20
lbcbcstf014.reno                    B40Pc4ca20
lbcbcstf014.srnb                    B40Pc4ca20
lbcbcsti000.olis                    B40Pc4ca20
lbcbcsti000.srol                    B40Pc4ca20
lbcbcstp000.ctpl                    B40Pc4ca20
lbcbcstp000.ctsr                    B40Pc4ca20
lbcbcstp000.egsr                    B40Pc4ca20
lbcbcstp004.ccur                    B40Pc4ca20
lbcbcstp004.cnln                    B40Pc4ca20
lbcbcstp004.cntr                    B40Pc4ca20
lbcbcstp004.cprj                    B40Pc4ca20
lbcbcstp004.cuno                    B40Pc4ca20
lbcbcstp004.dcsa                    B40Pc4ca20
lbcbcstp004.dsca                    B40Pc4ca20
lbcbcstp004.dscb                    B40Pc4ca20
lbcbcstp005.cact                    B40Pc4ca20
lbcbcstp005.cnln                    B40Pc4ca20
lbcbcstp005.cono                    B40Pc4ca20
lbcbcstp005.cprj                    B40Pc4ca20
lbcbcstp005.cspa                    B40Pc4ca20
lbcbcstp005.cstl                    B40Pc4ca20
lbcbcstp005.lkfd                    B40Pc4ca20
lbcbcstp005.uclk                    B40Pc4ca20
lbcbcstp005.upgf                    B40Pc4ca20
lbcbcsts000.ngms                    B40Pc4ca20
lbcbcsts007.ccom                    B40Pc4ca20
lbcbcsts007.ccon                    B40Pc4ca20
lbcbcsts007.csco                    B40Pc4ca20
lbcbcswh000.drjr                    B40Pc4ca20
lbcbcswh007.apsq                    B40Pc4ca20
lbcbcswh007.orno                    B40Pc4ca20
lbcbcswh007.pono                    B40Pc4ca20
lbcbcswh007.serb                    B40Pc4ca20
lbcbcswh007.serc                    B40Pc4ca20
lbcbcswh007.srnb                    B40Pc4ca20
lbcbcswh010.clot                    B40Pc4ca20
lbcbcswh010.cpsl                    B40Pc4ca20
lbcbcswh010.crcv                    B40Pc4ca20
lbcbcswh010.cvqu                    B40Pc4ca20
lbcbcswh010.koor                    B40Pc4ca20
lbcbcswh010.qapr                    B40Pc4ca20
lbcbcswh010.qpsl                    B40Pc4ca20
lbcbcswh010.qrcv                    B40Pc4ca20
lbcbcswh010.qrej                    B40Pc4ca20
lbcbcswh010.rcln                    B40Pc4ca20
lbcbcswh010.rcno                    B40Pc4ca20
lbcbcswh010.reno                    B40Pc4ca20
lbcbcswh010.rgfr                    B40Pc4ca20
lbcbcswh010.rgto                    B40Pc4ca20
lbcbcswh010.sqnb                    B40Pc4ca20
lbcbcswh010.srni                    B40Pc4ca20
lbcbcswh010.upsl                    B40Pc4ca20
lbcbcswh010.urcv                    B40Pc4ca20
lbcbcwsh009.seqn                    B40Pc4ca20
lbcinventory.trans                  B40Pc4ca20
lbcpurchase                         B40Pc4ca20
lbcreplenishment                    B40Pc4ca20
lbcsales                            B40Pc4ca20
Fbcsci0100m00012                    B40Pc4ca20
Fbcsfm0100m00042                    B40Pc4ca20
Fbcstc0100m00012                    B40Pc4ca20
Fbcstc0100m00022                    B40Pc4ca20
Fbcstc0100m00082                    B40Pc4ca20
Fbcstc0100m00092                    B40Pc4ca20
Fbcstd0100m00022                    B40Pc4ca20
Fbcstd0100m00032                    B40Pc4ca20
Fbcstd0100m00042                    B40Pc4ca20
Fbcstf0100m00012                    B40Pc4ca20
Fbcstf0100m00032                    B40Pc4ca20
Fbcstf0113m00012                    B40Pc4ca20
Fbcstf0114m00012                    B40Pc4ca20
Fbcsti0100m00012                    B40Pc4ca20
Fbcsti0100m00032                    B40Pc4ca20
Fbcstp0100m00012                    B40Pc4ca20
Fbcstp0100m00022                    B40Pc4ca20
Fbcstp0104m00012                    B40Pc4ca20
Fbcstp0105m00012                    B40Pc4ca20
Fbcsts0100m00022                    B40Pc4ca20
Fbcsts0107m00012                    B40Pc4ca20
Fbcswh0100m00012                    B40Pc4ca20
Fbcswh0107m00012                    B40Pc4ca20
Fbcswh0108m00012                    B40Pc4ca20
Fbcswh0109m00012                    B40Pc4ca20
Fbcswh0110m00012                    B40Pc4ca20
Fbcswh0110m10012                    B40Pc4ca20
Mbcstf0000100112                    B40Pc4ca20
Mbcstf0000200112                    B40Pc4ca20
Mbcstp0000200112                    B40Pc4ca20
Mbcsts0000100112                    B40Pc4ca20
Mbcsts0000200112                    B40Pc4ca20
Mbcsts0000300112                    B40Pc4ca20
Mbcswh0000200112                    B40Pc4ca20
hbcFCstc000.rcbl                    B40Pc4ca20
hbcFCstc000.rcdm                    B40Pc4ca20
hbcFCstc000.rcia                    B40Pc4ca20
hbcFCstc000.rcqt                    B40Pc4ca20
hbcFCstc000.rcrg                    B40Pc4ca20
hbcFCstc000.rcrj                    B40Pc4ca20
hbcFCstc000.rcte                    B40Pc4ca20
hbcFCstc000.tmtc                    B40Pc4ca20
hbcFCstc016.nprj                    B40Pc4ca20
hbcFCstf000.dlcd                    B40Pc4ca20
hbcFCstf000.dloc                    B40Pc4ca20
hbcFCstf000.losd                    B40Pc4ca20
hbcFCstf000.rcre                    B40Pc4ca20
hbcFCstf013.anbr                    B40Pc4ca20
hbcFCstf013.dkey                    B40Pc4ca20
hbcFCstf013.lkey                    B40Pc4ca20
hbcFCstf013.loca                    B40Pc4ca20
hbcFCstf014.orno                    B40Pc4ca20
hbcFCstf014.pono                    B40Pc4ca20
hbcFCstf014.rcno                    B40Pc4ca20
hbcFCstf014.srnb                    B40Pc4ca20
hbcFCstp000.ades                    B40Pc4ca20
hbcFCstp000.aser                    B40Pc4ca20
hbcFCstp000.cpac                    B40Pc4ca20
hbcFCstp000.ctpl                    B40Pc4ca20
hbcFCstp000.ctsr                    B40Pc4ca20
hbcFCstp004.cnln                    B40Pc4ca20
hbcFCstp004.cntr                    B40Pc4ca20
hbcFCstp004.cprj                    B40Pc4ca20
hbcFCstp004.cuno                    B40Pc4ca20
hbcFCstp004.dsca                    B40Pc4ca20
hbcFCstp004.dscb                    B40Pc4ca20
hbcFCsts000.ngms                    B40Pc4ca20
hbcFCsts007.ccon                    B40Pc4ca20
hbcFCsts007.csco                    B40Pc4ca20
hbcFCsts007.lmdt                    B40Pc4ca20
hbcFCsts007.lmtm                    B40Pc4ca20
hbcFCswh000.drjr                    B40Pc4ca20
hbcFCswh007.apno                    B40Pc4ca20
hbcFCswh007.apsq                    B40Pc4ca20
hbcFCswh007.orgn                    B40Pc4ca20
hbcFCswh008.orno                    B40Pc4ca20
hbcFCswh008.pono                    B40Pc4ca20
hbcFCswh008.seqn                    B40Pc4ca20
hbcFCswh010.koor                    B40Pc4ca20
hbcFCswh010.orno                    B40Pc4ca20
hbcFCswh010.pono                    B40Pc4ca20
hbcFCswh010.rcln                    B40Pc4ca20
hbcFCswh010.rcno                    B40Pc4ca20
hbcFCswh010.reno                    B40Pc4ca20
hbcFCswh010.srnb                    B40Pc4ca20
hbcFCswh010.srni                    B40Pc4ca20
hbcFDstf000.dloc                    B40Pc4ca20
hbcFIstf000.dlcd                    B40Pc4ca20
hbcFIstf000.dloc                    B40Pc4ca20
hbcFIstf013.anbr                    B40Pc4ca20
hbcFIstf013.dkey                    B40Pc4ca20
hbcFIstf013.lkey                    B40Pc4ca20
hbcFIstf013.loca                    B40Pc4ca20
hbcFIstf014.rcln                    B40Pc4ca20
hbcFOstf0114m0001                   B40Pc4ca20
hbcSEstc0100m000                    B40Pc4ca20
hbcSEstc0117m000                    B40Pc4ca20
hbcSEstc0131m000                    B40Pc4ca20
hbcSEstc0207s000                    B40Pc4ca20
hbcSEstf0109m000                    B40Pc4ca20
hbcSEstf0113m000                    B40Pc4ca20
hbcSEstf0114m000                    B40Pc4ca20
hbcSEstp0104m000                    B40Pc4ca20
hbcSEstp0105m000                    B40Pc4ca20
hbcSEsts0105m000                    B40Pc4ca20
hbcSEsts0107m000                    B40Pc4ca20
hbcSEswh0110m000                    B40Pc4ca20
hbcSEswh0110m100                    B40Pc4ca20
hbcSFstc00010sf0060                 B40Pc4ca20
